<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Class WAEF_Admin.
 *
 * WAEF_Admin class handles stuff for admin.
 *
 * @class       WAEF_Admin
 * @author     	multisquares
 * @package		WooCommerce Advanced Extra Fees Lite
 * @version		1.0.1
 */
class WAEF_Admin {

        /**
	 * Form option fields.
	 * @var array
	 */
	public $form_fields = array();
        
	/**
	 * Constructor.
	 *
	 * @since 1.0.5
	 */
	public function __construct() {
                $this->id                 = 'advanced_extra_fees';
		// Initialize components
		add_action( 'admin_init', array( $this, 'init' ) );
	}


	/**
	 * Initialize class components.
	 *
	 * @since 1.0.0
	 */
	public function init() {
           
		global $pagenow;
                if(isset($_GET['page']) && !empty($_GET['page']) && $_GET['page'] == 'waef'){
                    
                    do_action( 'Woocommerce_Advanced_Extra_Fees_method_init' );
                   
                    $this->init_form_fields();
                }                
                
		// Add to WC Screen IDs to load scripts.
		add_filter( 'woocommerce_screen_ids', array( $this, 'add_waef_screen_ids' ) );
                
		// Enqueue scripts
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
                
        add_action('admin_notices', array($this,'waef_add_plugin_notice'));      
                // Keep WC menu open while in WAEF edit screen
		add_action( 'admin_head', array( $this, 'menu_highlight' ) );

		if ( 'plugins.php' == $pagenow ) :
			// Plugins page
			add_filter( 'plugin_action_links_' . plugin_basename( WooCommerce_Advanced_Extra_Fees()->file ), array( $this, 'add_plugin_action_links' ), 10, 2 );
		endif;
                
                

	}
        
	/**
	 * Init fields.
	 *
	 * Add fields to the WAEF settings page.
	 *
	 * @since 1.0.0
	 */
	public function init_form_fields() {

		$this->form_fields = array(
			'enabled' => array(
				'title'   => __( 'Enable/Disable', 'woocommerce' ),
				'type'    => 'checkbox',
				'label'   => __( 'Enable Advanced Extra Fees', 'woocommerce-advanced-extra-fees' ),
				'default' => 'yes'
			),
			'hide_other_shipping_when_available' => array(
				'title'   => __( 'Hide other shipping', 'woocommerce-advanced-extra-fees' ),
				'type'    => 'checkbox',
				'label'   => __( 'Hide other fees when free shipping is available', 'woocommerce-advanced-extra-fees' ),
				'default' => 'no'
			),
			'waef_shipping_rates_table'           => array(
				'type' => 'waef_shipping_rates_table',
			),
		);

	}

	/**
	 * Screen IDs.
	 *
	 * Add 'waef' to the screen IDs so the WooCommerce scripts are loaded.
	 *
	 * @since 1.0.5
	 *
	 * @param  array $screen_ids List of existing screen IDs.
	 * @return array             List of modified screen IDs.
	 */
	public function add_waef_screen_ids( $screen_ids ) {

		$screen_ids[] = 'waef';

		return $screen_ids;

	}

	/**
	 * Enqueue scripts.
	 *
	 * Enqueue style and java scripts.
	 *
	 * @since 1.0.5
	 */
	public function admin_enqueue_scripts() {

		// Only load scripts on relvant pages
		if (
			( isset( $_REQUEST['post'] ) && 'waef' == get_post_type( $_REQUEST['post'] ) ) ||
			( isset( $_REQUEST['post_type'] ) && 'waef' == $_REQUEST['post_type'] ) ||
			( isset( $_REQUEST['section'] ) && 'waef_advanced_extra_fees_method' == $_REQUEST['section'] || isset($_GET['page']) == 'waef' )
		) :

			// Style script
			wp_enqueue_style( 'woocommerce-advanced-extra-fees-css', plugins_url( 'assets/admin/css/woocommerce-advanced-extra-fees.css', WooCommerce_Advanced_Extra_Fees()->file ), array(), WooCommerce_Advanced_Extra_Fees()->version );

			// Javascript
			wp_enqueue_script( 'woocommerce-advanced-extra-fees-js', plugins_url( 'assets/admin/js/woocommerce-advanced-extra-fees.js', WooCommerce_Advanced_Extra_Fees()->file ), array( 'jquery', 'jquery-ui-sortable', 'jquery-blockui' ), WooCommerce_Advanced_Extra_Fees()->version, true );

			wp_localize_script( 'woocommerce-advanced-extra-fees-js', 'waef', array('nonce' => wp_create_nonce( 'waef-ajax-nonce' ),
			) );

		endif;

	}


	/**
	 * Keep menu open.
	 *
	 * Highlights the correct top level admin menu item for post type add screens.
	 *
	 * @since 1.0.5
	 */
	public function menu_highlight() {
                
		global $parent_file, $post_type; //$parent_file, $submenu_file, $post_type

		if ( 'waef' == $post_type ) :
			$parent_file  = 'waef';
//			$submenu_file = 'wc-settings';
		endif;

	}


	/**
	 * Plugin action links.
	 *
	 * Add links to the plugins.php page below the plugin name
	 * and besides the 'activate', 'edit', 'delete' action links.
	 *
	 * @since 1.0.0
	 *
	 * @param  array  $links List of existing links.
	 * @param  string $file  Name of the current plugin being looped.
	 * @return array         List of modified links.
	 */
	public function add_plugin_action_links( $links, $file ) {

		if ( $file == plugin_basename( WooCommerce_Advanced_Extra_Fees()->file ) ) :
			$links = array_merge( array(
				'<a href="' . esc_url( admin_url( '/admin.php?page=waef' ) ) . '">' . __( 'Settings', 'woocommerce-advanced-extra-fees' ) . '</a>'
			), $links );
			$links = array_merge( array(
				'<a style="color: red;font-weight: 700;"href="http://bit.ly/2KHaO4U">' . __( 'Upgrade To Pro', 'woocommerce-advanced-extra-fees' ) . '</a>'
			), $links );
		endif;

		return $links;

	}

	/**
	 * Plugin review notice.
	 *
	 * Add plugin review notice in wordpress dashboard.
	 *
	 * @since 1.0.0
	 *
	 */
	public function waef_add_plugin_notice() {


		global $pagenow; 
		?>
		<div class="notice notice-info is-dismissible waef-review-notice">
			<p><?php _e( 'You are currently using the Community version of the WooCommerce Advanced Extra Fees Plugin. Premium users are provided with an additional features and priority support. Upgrade to Premium today to reap all the benefits.' ); ?></p><p><a style="background: #0176b2;padding: 7px;color: #fff;border-radius: 3px;cursor: pointer;text-decoration: none;" href="http://bit.ly/2KHaO4U">Buy Now</a></p>
		</div>
		<?php
		if ( get_option( 'waef_review_notice_dismissed' ) !== false ) {
			return;
		} else {
		    if ( isset( $_GET['waef_dismis_review'] ) ) {
				update_option( 'waef_review_notice_dismissed', true );
				return;
			}
		}
		?>
			<div class="notice notice-info is-dismissible waef-review-notice">
						
					<p><?php _e( 'It would mean a lot to us if you would quickly give our plugin a 5-star rating. Your Review is very important to us as it helps us to grow more!', 'woocommerce-advanced-extra-fees' ); ?></p>
					<ul>
						<li><a href="https://wordpress.org/support/plugin/woo-advanced-extra-fees-lite/reviews/?rate=5#new-post" class="button"><?php _e( 'Yes you deserve it!', 'woocommerce-advanced-extra-fees' ); ?></span></a></li>
						<li><a href="<?php echo esc_url( add_query_arg( 'waef_dismis_review', true ) ); ?>" class="waef-dismiss"><?php _e( 'Hide this message', 'woocommerce-advanced-extra-fees' ); ?> / <?php _e( 'Already did!', 'woocommerce-advanced-extra-fees' ); ?></a></li>
						<li><a href="mailto:info@idomit.com?Subject=Here%20is%20how%20I%20think%20you%20can%20do%20better"><?php _e( 'Actually, I need a help...', 'woocommerce-advanced-extra-fees' ); ?></a></li>
					</ul>
			</div>
			<?php
	}

}
