<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Class WAEF_Post_Type.
 *
 * Initialize the waef post type.
 *
 * @class		WAEF_post_type
 * @author		multisquares
 * @package		WooCommerce Advanced Extra Fees Lite
 * @version		1.0.0
 */
class WAEF_Post_Type {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
            
                $this->id                 = 'advanced_extra_fees';
		$this->title              = __( 'Fees (configurable per rate)', 'woocommerce-advanced-extra-fees' );
		$this->method_title       = __( 'Advanced Extra Fees', 'woocommerce-advanced-extra-fees' );
		$this->method_description = __( 'Configure WooCommerce Fees', 'woocommerce-advanced-extra-fees' );
                
                do_action( 'Woocommerce_Advanced_Extra_Fees_method_init' );
               
		// Register post type
		add_action( 'init', array( $this, 'waef_register_post_type' ) );

		// Add/save meta boxes
		add_action( 'add_meta_boxes', array( $this, 'waef_post_type_meta_box' ) );
		add_action( 'save_post', array( $this, 'waef_save_meta' ) );
		add_action( 'save_post', array( $this, 'waef_save_condition_meta' ) );

		// Edit user notices
		add_filter( 'post_updated_messages', array( $this, 'waef_custom_post_type_messages' ) );

		// Redirect after delete
		add_action( 'load-edit.php', array( $this, 'waef_redirect_after_trash' ) );
                

	}
	/**
	 * Post type.
	 *
	 * Register the 'waef' post type.
	 *
	 * @since 1.0.0
	 */
	public function waef_register_post_type() {

		$labels = array(
			'name'               => __( 'Advanced Extra Fees', 'woocommerce-advanced-extra-fees' ),
			'singular_name'      => __( 'Advanced Fees', 'woocommerce-advanced-extra-fees' ),
			'add_new'            => __( 'Add New', 'woocommerce-advanced-extra-fees' ),
			'add_new_item'       => __( 'Add New Advanced Fees', 'woocommerce-advanced-extra-fees' ),
			'edit_item'          => __( 'Edit Advanced Fees', 'woocommerce-advanced-extra-fees' ),
			'new_item'           => __( 'New Advanced Fees', 'woocommerce-advanced-extra-fees' ),
			'view_item'          => __( 'View Advanced Fees', 'woocommerce-advanced-extra-fees' ),
			'search_items'       => __( 'Search Advanced Fees', 'woocommerce-advanced-extra-fees' ),
			'not_found'          => __( 'No Advanced Fees', 'woocommerce-advanced-extra-fees' ),
			'not_found_in_trash' => __( 'No Advanced Fees found in Trash', 'woocommerce-advanced-extra-fees' ),
		);

		register_post_type( 'waef', array(
			'label'           => 'waef',
			'show_ui'         => true,
			'show_in_menu'    => false,
			'capability_type' => 'post',
			'map_meta_cap'    => true,
			'rewrite'         => array( 'slug'=> 'waef', 'with_front'=> true ),
			'_builtin'        => false,
			'query_var'       => true,
			'supports'        => array( 'title' ),
			'labels'          => $labels,
		) );

	}


	/**
	 * Messages.
	 *
	 * Modify the notice messages text for the 'waef' post type.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $messages Existing list of messages.
	 * @return array           Modified list of messages.
	 */
	function waef_custom_post_type_messages( $messages ) {

		$post             = get_post();
		$post_type        = get_post_type( $post );
		$post_type_object = get_post_type_object( $post_type );

		$messages['waef'] = array(
			0 => '',
			1 => __( 'Advanced fees updated.', 'woocommerce-advanced-extra-fees' ),
			2 => __( 'Custom field updated.', 'woocommerce-advanced-extra-fees' ),
			3 => __( 'Custom field deleted.', 'woocommerce-advanced-extra-fees' ),
			4 => __( 'Advanced fees updated.', 'woocommerce-advanced-extra-fees' ),
			5 => isset( $_GET['revision'] ) ?
				sprintf( __( 'Advanced fees restored to revision from %s', 'woocommerce-advanced-extra-fees' ), wp_post_revision_title( (int) $_GET['revision'], false ) )
				: false,
			6 => __( 'Advanced fees published.', 'woocommerce-advanced-extra-fees' ),
			7 => __( 'Advanced fees saved.', 'woocommerce-advanced-extra-fees' ),
			8 => __( 'Advanced fees submitted.', 'woocommerce-advanced-extra-fees' ),
			9 => sprintf(
				__( 'Advanced fees scheduled for: <strong>%1$s</strong>.', 'woocommerce-advanced-extra-fees' ),
				date_i18n( __( 'M j, Y @ G:i', 'woocommerce-advanced-extra-fees' ), strtotime( $post->post_date ) )
			),
			10 => __( 'Advanced fees draft updated.', 'woocommerce-advanced-extra-fees' ),
		);

		$permalink     = admin_url( '/admin.php?page=waef' );
		$overview_link = sprintf( ' <a href="%s">%s</a>', esc_url( $permalink ), __( 'Return to Fees overview.', 'woocommerce-advanced-extra-fees' ) );
		$messages['waef'][1] .= $overview_link;
		$messages['waef'][6] .= $overview_link;
		$messages['waef'][9] .= $overview_link;
		$messages['waef'][8] .= $overview_link;
		$messages['waef'][10] .= $overview_link;

		return $messages;

	}


	/**
	 * Meta boxes.
	 *
	 * Add two meta boxes to the 'waef' post type.
	 *
	 * @since 1.0.0
	 */
	public function waef_post_type_meta_box() {

		add_meta_box( 'waef_conditions', __( 'Advanced Fees conditions', 'woocommerce-advanced-extra-fees' ), array( $this, 'render_waef_conditions' ), 'waef', 'normal' );
		add_meta_box( 'waef_settings', __( 'Fees settings', 'woocommerce-advanced-extra-fees' ), array( $this, 'render_waef_settings' ), 'waef', 'normal' );

	}


	/**
	 * Render meta box.
	 *
	 * Get conditions meta box contents.
	 *
	 * @since 1.0.0
	 */
	public function render_waef_conditions() {

		/**
		 * Load meta box conditions view
		 */
		require_once plugin_dir_path( __FILE__ ) . 'admin/settings/meta-box-conditions.php';

	}


	/**
	 * Render meta box.
	 *
	 * Get settings meta box contents.
	 *
	 * @since 1.0.0
	 */
	public function render_waef_settings() {

		/**
		 * Load meta box settings view
		 */
		require_once plugin_dir_path( __FILE__ ) . 'admin/settings/meta-box-settings.php';

	}


	/**
	 * Save meta.
	 *
	 * Validate and save post meta. This value contains all
	 * the normal fees settings (no conditions).
	 *
	 * @since 1.0.0
	 *
	 * @param int/numberic $post_id ID of the post being saved.
	 */
	public function waef_save_meta( $post_id ) {

		if ( ! isset( $_POST['waef_settings_meta_box_nonce'] ) ) {
			return $post_id;
		}

		$nonce = $_POST['waef_settings_meta_box_nonce'];

		if ( ! wp_verify_nonce( $nonce, 'waef_settings_meta_box' ) ) {
			return $post_id;
		}

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return $post_id;
		}

		if ( ! current_user_can( 'manage_woocommerce' ) ) {
			return $post_id;
		}

		$shipping_method = $_POST['_waef_shipping_method'];
		$shipping_method['fees_title'] 	= sanitize_text_field( $shipping_method['fees_title'] );
		$shipping_method['fees_cost'] 	= preg_replace( '/[^0-9\%\.\,\-]/', '', $shipping_method['fees_cost'] );
		$shipping_method['tax'] 	= 'taxable' == $shipping_method['tax'] ? 'taxable' : 'not_taxable';

		update_post_meta( $post_id, '_waef_shipping_method', $shipping_method );

		do_action( 'waef_save_shipping_settings', $post_id );

	}


	/**
	 * Save meta.
	 *
	 * Validate and save condition meta box conditions meta. This
	 * value contains all the fees conditions.
	 *
	 * @since 1.0.0
	 *
	 * @param int/numberic $post_id ID of the post being saved.
	 */
	public function waef_save_condition_meta( $post_id ) {

		if ( ! isset( $_POST['waef_conditions_meta_box_nonce'] ) ) :
			return $post_id;
		endif;

		$nonce = $_POST['waef_conditions_meta_box_nonce'];

		if ( ! wp_verify_nonce( $nonce, 'waef_conditions_meta_box' ) ) :
			return $post_id;
		endif;

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) :
			return $post_id;
		endif;

		if ( ! current_user_can( 'manage_woocommerce' ) ) :
			return $post_id;
		endif;

		$conditions = $_POST['_waef_conditions'];

		update_post_meta( $post_id, '_waef_conditions', $conditions );

		do_action( 'waef_save_shipping_conditions', $post_id );

	}


	/**
	 * Redirect trash.
	 *
	 * Redirect user after trashing a WAEF post.
	 *
	 * @since 1.0.0
	 */
	public function waef_redirect_after_trash() {

		$screen = get_current_screen();

		if ( 'edit-waef' == $screen->id ) :

			if ( isset( $_GET['trashed'] ) && intval( $_GET['trashed'] ) > 0 ) :

				$redirect = admin_url( '/admin.php?page=wc-settings&tab=shipping&section=waef_advanced_extra_fees_method' );
				wp_redirect( $redirect );
				exit();

			endif;

		endif;

	}


}

/**
 * Load condition object
 */
require_once plugin_dir_path( __FILE__ ) . 'admin/settings/conditions/class-waef-condition.php';
