<?php
/**
 * Plugin Name: 	WooCommerce Advanced Extra Fees Lite
 * Plugin URI: 		https://www.idomit.com/
 * Description: 	WooCommerce Advanced Extra Fees Plugins allows you to configure advanced fees conditions with <strong>conditional logic!</strong>
 * Version: 		1.0.9
 * Author: 		idomit
 * Author URI: 		https://www.idomit.com/
 * Text Domain: 	woocommerce-advanced-extra-fees
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Copyright multisquares
 * Class Woocommerce_Advanced_Extra_Fees
 *
 * Main WAEF class, add filters and handling all other files
 *
 * @class		Woocommerce_Advanced_Extra_Fees
 * @version		1.0.0
 * @author		multisquares
 */
class WooCommerce_Advanced_Extra_Fees {


	/**
	 * Version.
	 *
	 * @since 1.0.1
	 * @var string $version Plugin version number.
	 */
	public $version = '1.0.9';


	/**
	 * File.
	 *
	 * @since 1.0.5
	 * @var string $file Plugin __FILE__ path.
	 */
	public $file = __FILE__;


	/**
	 * Instance of WooCommerce_Advanced_Extra_Fees.
	 *
	 * @since 1.0.1
	 * @access private
	 * @var object $instance The instance of WAEF.
	 */
	private static $instance;


	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
                $this->id                 = 'advanced_extra_fees';
                $this->title              = __( 'Fees (configurable per rate)', 'woocommerce-advanced-extra-fees' );
                $this->method_title       = __( 'Advanced Extra Fees', 'woocommerce-advanced-extra-fees' );
                $this->method_description = __( 'Configure WooCommerce Advanced Extra Fees Lite', 'woocommerce-advanced-extra-fees' );

		// Check if WooCommerce is active
		if ( ! function_exists( 'is_plugin_active_for_network' ) ) :
			require_once( ABSPATH . '/wp-admin/includes/plugin.php' );
		endif;

		if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) :
			if ( ! is_plugin_active_for_network( 'woocommerce/woocommerce.php' ) ) :
				return;
			endif;
		endif;

		// Initialize plugin parts
		$this->init();

		do_action( 'Woocommerce_Advanced_Extra_Fees_init' );

	}
        
        
	/**
	 * Instance.
	 *
	 * An global instance of the class. Used to retrieve the instance
	 * to use on other files/plugins/themes.
	 *
	 * @since 1.0.1
	 *
	 * @return object Instance of the class.
	 */
	public static function instance() {

		if ( is_null( self::$instance ) ) :
			self::$instance = new self();
		endif;

		return self::$instance;

	}


	/**
	 * Init.
	 *
	 * Initialize plugin parts.
	 *
	 * @since 1.0.1
	 */
	public function init() {
                
                
		// Add hooks/filters
		$this->waef_hooks();

		// Load textdomain
		$this->load_textdomain();

		/**
		 * Require matching conditions hooks.
		 */
		require_once plugin_dir_path( __FILE__ ) . '/includes/class-waef-match-conditions.php';
		$this->matcher = new WAEF_Match_Conditions();

		/**
		 * Post Type class
		 */
		require_once plugin_dir_path( __FILE__ ) . 'includes/class-waef-post-type.php';
		$this->post_type = new WAEF_Post_Type();

		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) :

			/**
			 * Load ajax methods
			 */
			require_once plugin_dir_path( __FILE__ ) . '/includes/class-waef-ajax.php';
			$this->ajax = new WAEF_Ajax();

		endif;

		if ( is_admin() ) :

			/**
			 * Admin class.
			 */
			require_once plugin_dir_path( __FILE__ ) . '/includes/admin/class-waef-admin.php';
			$this->admin = new WAEF_Admin();

		endif;

	}


	/**
	 * Hooks.
	 *
	 * Initialize plugin hooks like actions and filters.
	 *
	 * @since 1.0.0
	 */
	public function waef_hooks() {
                
                if ( ! is_admin() ) :
                    // Initialize shipping method class
                    add_action( 'init', array( $this, 'waef_fees_method' ) );
                endif;                
  
                // Admin Menu
                add_action( 'admin_menu', array( $this, 'add_waef_menu_item' ) );

	}     
        /**
	 * Plugin Menu.
	 *
	 * Add 'waef' to the screen IDs so the WooCommerce scripts are loaded.
	 *
	 * @since 1.0.5
	 *
	 * @param  array $screen_ids List of existing screen IDs.
	 * @return array             List of modified screen IDs.
	 */
	public function add_waef_menu_item() {
               
                add_menu_page( 'Advanced Extra Fees', 'Advanced Extra Fees', 'manage_options', 'waef', array($this,'generate_waef_shipping_rates_table_html_view'), plugins_url( '/assets/admin/images/waeficon.png',__FILE__ ), 5);
	}
        
        
          /**
	 * Settings tab table.
	 *
	 * Load and render the table on the Advanced Fees settings tab.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function generate_waef_shipping_rates_table_html_view() {
            ob_start();
                    /**
                     * Load conditions table file
                     */
                    require plugin_dir_path( __FILE__ ) . 'includes/admin/views/waef-shipping-rates-table.php';

            return;
            
            ob_get_clean();

	}

	/**
	 * Textdomain.
	 *
	 * Load the textdomain based on WP language.
	 *
	 * @since 1.0.1
	 */
	public function load_textdomain() {

		// Load textdomain
		load_plugin_textdomain( 'woocommerce-advanced-extra-fees', false, basename( dirname( __FILE__ ) ) . '/languages' );

	}


	/**
	 * Add fees method.
	 *
	 * Configure and add all the fees available.
	 *
	 * @since 1.0.0
	 */
	public function waef_fees_method() {

		require_once plugin_dir_path( __FILE__ ) . 'includes/waef-match-fee-add-cart.php';
		$this->waef_method = new WAEF_advanced_extra_fees_Method();

	}


}


/**
 * The main function responsible for returning the WooCommerce_Advanced_Extra_Fees object.
 *
 * Use this function like you would a global variable, except without needing to declare the global.
 *
 * Example: <?php WooCommerce_Advanced_Extra_Fees()->method_name(); ?>
 *
 * @since 1.0.1
 *
 * @return object WooCommerce_Advanced_Extra_Fees class object.
 */
if ( ! function_exists( 'WooCommerce_Advanced_Extra_Fees' ) ) :

	function WooCommerce_Advanced_Extra_Fees() {
		return WooCommerce_Advanced_Extra_Fees::instance();

	}


endif;

// Backwards compatibility
if ( ! function_exists( 'WAEF' ) ) :
	function WAEF() {
		return WooCommerce_Advanced_Extra_Fees();

	}
endif;
WooCommerce_Advanced_Extra_Fees();
